betty.test_utils.config.collections package - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.test_utils.config.collections package

## Submodules

- betty.test_utils.config.collections.mapping module
  - `ConfigurationMappingTestBase`
    - `ConfigurationMappingTestBase.test___iter__()`
- betty.test_utils.config.collections.sequence module
  - `ConfigurationSequenceTestBase`
    - `ConfigurationSequenceTestBase.get_configuration_keys()`
    - `ConfigurationSequenceTestBase.test___iter__()`

## Module contents

Test utilities for `betty.config.collections`.

class betty.test_utils.config.collections.ConfigurationCollectionTestBase

  Bases: `Generic`[`_ConfigurationKeyT`, `_ConfigurationT`]

  A base class for testing `betty.config.collections.ConfigurationCollection` implementations.

  get_configuration_keys() → tuple[_ConfigurationKeyT, _ConfigurationKeyT, _ConfigurationKeyT, _ConfigurationKeyT]

    Produce four configuration keys to test the collection with.

  get_configurations() → tuple[_ConfigurationT, _ConfigurationT, _ConfigurationT, _ConfigurationT]

    Produce four configuration items to test the collection with.

  get_sut(configurations: Iterable[_ConfigurationT] | None = None) → ConfigurationCollection[_ConfigurationKeyT, _ConfigurationT]

    Produce the collection under test.

  async test___delitem__() → None

    Tests `betty.config.collections.ConfigurationCollection.__delitem__()` implementations.

  async test___eq__() → None

    Tests `betty.config.collections.ConfigurationCollection.__eq__()` implementations.

  async test___getitem__() → None

    Tests `betty.config.collections.ConfigurationCollection.__getitem__()` implementations.

  async test___iter__() → None

    Tests `betty.config.collections.ConfigurationCollection.__iter__()` implementations.

  async test___len__() → None

    Tests `betty.config.collections.ConfigurationCollection.__len__()` implementations.

  async test_append() → None

    Tests `betty.config.collections.ConfigurationCollection.append()` implementations.

  async test_insert() → None

    Tests `betty.config.collections.ConfigurationCollection.insert()` implementations.

  async test_keys() → None

    Tests `betty.config.collections.ConfigurationCollection.keys()` implementations.

  async test_load_item() → None

    Tests `betty.config.collections.ConfigurationCollection.load_item()` implementations.

  async test_move_to_beginning() → None

    Tests `betty.config.collections.ConfigurationCollection.move_to_beginning()` implementations.

  async test_move_to_end() → None

    Tests `betty.config.collections.ConfigurationCollection.move_to_end()` implementations.

  async test_move_towards_beginning() → None

    Tests `betty.config.collections.ConfigurationCollection.move_towards_beginning()` implementations.

  async test_move_towards_end() → None

    Tests `betty.config.collections.ConfigurationCollection.move_towards_end()` implementations.

  async test_prepend() → None

    Tests `betty.config.collections.ConfigurationCollection.prepend()` implementations.

  async test_replace_with_items() → None

    Tests `betty.config.collections.ConfigurationCollection.replace()` implementations.

  async test_replace_without_items() → None

    Tests `betty.config.collections.ConfigurationCollection.replace()` implementations.

  async test_values() → None

    Tests `betty.config.collections.ConfigurationCollection.values()` implementations.